# Altera FPGA Boards

The {py:mod}`torii_boards.altera` module provides a collection of Altera FPGA development boards, they are based off the Torii {py:class}`AlteraPlatform <torii.platform.vendor.altera.AlteraPlatform>` platform and support the [Quartus] and [Mistral] toolchains.

```{toctree}
:maxdepth: 2
cyclone_iii
cyclone_iv
cyclone_v
max10
```

[Quartus]: https://www.intel.com/content/www/us/en/products/details/fpga/development-tools/quartus-prime.html
[Mistral]: https://github.com/Ravenslofty/mistral
